import React, { useRef, useEffect } from "react";
let observer;
const callBackMap = new WeakMap();
function init() {
  if (observer)
    return;
  observer = new ResizeObserver((entries) => {
    entries.forEach((entry) => {
      const maybeCallBacks = callBackMap.get(entry.target);
      const safeCallBacks = maybeCallBacks != null ? maybeCallBacks : [];
      safeCallBacks.forEach((cb) => cb.current(entry));
    });
  });
}
function useResizeObserver(node, callback) {
  const callbackRef = useRef(() => void 0);
  callbackRef.current = callback;
  useEffect(init, []);
  useEffect(() => {
    if (node) {
      const maybeCallBacks = callBackMap.get(node);
      const safeCallBacks = maybeCallBacks != null ? maybeCallBacks : [];
      const newCallbacks = safeCallBacks.concat(callbackRef);
      callBackMap.set(node, newCallbacks);
      observer.observe(node);
    }
    return () => {
      if (node) {
        const maybeCallBacks = callBackMap.get(node);
        const safeCallBacks = maybeCallBacks != null ? maybeCallBacks : [];
        const newCallbacks = safeCallBacks.filter((ref) => ref !== callbackRef);
        callBackMap.set(node, newCallbacks);
        if (newCallbacks.length === 0) {
          observer.unobserve(node);
        }
      }
    };
  }, [node]);
}
const useContainterQuery = (node, width = 1, maxWidth) => {
  if (maxWidth !== void 0 && maxWidth <= width) {
    throw new Error(`The second width value, ${maxWidth}, is not larger than ${width}. Please provide a value greater than first width value`);
  }
  const [matches, setMatch] = React.useState(false);
  const callBack = (entry) => {
    var _a, _b;
    const nodeWidth = (_b = (_a = entry.borderBoxSize) == null ? void 0 : _a.inlineSize) != null ? _b : entry.contentRect.width;
    if (nodeWidth > 0) {
      const newMatch = maxWidth === void 0 ? nodeWidth <= width : nodeWidth >= width && nodeWidth <= maxWidth;
      setMatch(newMatch);
    }
  };
  useResizeObserver(node, callBack);
  return matches;
};
export { useContainterQuery as default };
